<#-- Import common macros and functions -->
<#import "traversal_utils.ftl" as utils>
<#import "macros_common_general.ftl" as com>
<#compress>
<#-- Initialize common variables -->
<@com.initializeMainVariables/>
<#if _subject.submissionType?has_content && _subject.submissionType?matches("EU_PPP_.*")>
	<@com.initiRelevanceForPPP relevance/>
</#if>
<#-- Root entity -->
<#assign rootEntity = entity.root>
<#-- Define the main macro and the arguments to be used to get output using the traversal approach -->
<#assign mainMacroName = "printLiteratureReferencesForDocument"/>
<#assign mainMacroArgs = ['sectionDoc', 'sectionNode', 'entityDocument', 'level']/>
<#-- Make global the macroCall as well as each macro used in it -->
<#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
<#global printLiteratureReferencesForDocument=printLiteratureReferencesForDocument/>
<#-- Print CSV header row -->
<@printCsvHeadersRow />
<#-- Do the traverse -->
<@utils.traversal rootEntity 8/>

<#----------------------------------------------->
<#-- Macro and function definitions start here -->
<#----------------------------------------------->
<#macro printLiteratureReferencesForDocument sectionDoc sectionNode entityDocument level>

	<#if level==0>
		<#assign listOfReferences = getReferencedLitRefEntitiesFromDoc(sectionDoc) >
    	<#if listOfReferences?has_content>
			<#list listOfReferences as literatureReferenceDpList>

				<#local literatureReference=literatureReferenceDpList[0]/>
				<#local dataPr=literatureReferenceDpList[1]/>

				<#if literatureReference?has_content>

					<#-- Get the section name -->
					<#local sectionName = "" />
					<#if sectionNode?has_content>
						<#if sectionNode.number?has_content>
							<#local sectionName = sectionNode.number + " ">
						</#if>
						<#local sectionName = sectionName + sectionNode.title>
					</#if>

					<#-- The web URL pointing to the document -->
					<#local docUrl=utils.getDocumentUrl(sectionDoc) />

					<@tableOutput literatureReference sectionName sectionDoc docUrl entityDocument dataPr/>
				</#if>
			</#list>
		</#if>
    </#if>     
</#macro>

<#function getReferencedLitRefEntitiesFromDoc docElementNode>
    <#local listOfLiteratureReferences = [] />

    <#if docElementNode?node_type == "document_reference">
      <#local listOfLiteratureReferences = checkAndAddLiteraturReferenceWithDP(docElementNode, docElementNode, listOfLiteratureReferences) />
      <#return listOfLiteratureReferences />
    </#if>

    <#if docElementNode?node_type == "document_references">
      <#list docElementNode as item>
        <#local listOfLiteratureReferences = checkAndAddLiteraturReferenceWithDP(item, docElementNode, listOfLiteratureReferences) />
      </#list>
      <#return listOfLiteratureReferences />
    </#if>
    
    <#if docElementNode?children?has_content>   
      <#list docElementNode?children as child>
      <#local listOfLiteratureReferences = listOfLiteratureReferences + getReferencedLitRefEntitiesFromDoc(child)  />
      </#list>
    </#if>
    <#return listOfLiteratureReferences/>
</#function>

<#-- This function is a new version of the one above, in order to include both the lit reference and data protection claim -->
<#function checkAndAddLiteraturReferenceWithDP docKey docNode listOfReferencedEntities>
	<#local doc = iuclid.getDocumentForKey(docKey) />
	<#if doc?has_content && doc.documentType == "LITERATURE">
	  	<#list listOfReferencedEntities as docDpList>
	  		<#local document=docDpList[0]/>
	    	<#if document.documentKey == doc.documentKey>
	      		<#return listOfReferencedEntities>
	    	</#if>
	  	</#list>
	  	
	  	<#-- get DP -->
	  	<#local dataProt=""/>
	  	<#local docKeyParents=docNode?ancestors/>
	  	<#if docKeyParents?has_content>
	  		<#local docKeyParent = docKeyParents[0]/>
  			<#if docKeyParent.hasElement("DataProtectionClaimed")>
  				<#local dataProt=docKeyParent.DataProtectionClaimed/>
  			<#else>
  				<#local dataProt="N/A"/>
  			</#if>  
  		</#if> 
  		
  		<#-- add -->
  		<#local newLitEntry = [doc, dataProt]/>
		<#return listOfReferencedEntities + [newLitEntry]>
  	</#if>
  	<#return listOfReferencedEntities>
</#function>

<#macro printCsvHeadersRow>
"Entity Type","Entity Name","Section Name","Document Name","GLP","Confidentiality Claim","Confidentiality Justification","Data Protection Claimed","Data Protection Justification",<#if pppRelevant??>"Previously Used",</#if>"Literature Type","Literature Author","Literature Title","Literature Year","Literature Report No","Literature Report Date","Literature Study Number","Literature Source","Literature Study Sponsor","Literature Test Facility","Literature Remarks","Literature Other Study Identifier(s)"
</#macro>
</#compress>

<#-- This function checks if the document exists in the change log and retrieves the status -->
<#function getChangeLogStatus study entity>

	<#local changeLogFlag="no"/>
	<#local changeLogEntryList=[]/>
	<#local changeLogs = iuclid.getSectionDocumentsForParentKey(entity.documentKey, "FLEXIBLE_RECORD", "ChangeLog") />
	<#list changeLogs as changeLog>
		<#list changeLog.ChangeLog.ChangeLogEntries as changeLogEntry>
			<#local changeLogDoc=iuclid.getDocumentForKey(changeLogEntry.LinkToDocument)/>

			<#if changeLogDoc?has_content>
				<#if study.documentKey.uuid==changeLogDoc.documentKey.uuid>
					<#local changeLogStatus><@com.picklist changeLogEntry.Status/></#local>
					<#if changeLogStatus?has_content>
						<#if !(changeLogStatus?starts_with("new"))>
							<#local changeLogFlag="yes"/>
						</#if>
						<#-- <#local changeLogStatusList = changeLogStatusList + [changeLogStatus]/> -->
						<#local changeLogEntryList = changeLogEntryList + [changeLogEntry]/>
					</#if>
				</#if>
			</#if>
		</#list>
	</#list>
	
	<#local changeLogStatusMessage>
		<@compress single_line=true>
		${changeLogFlag}
		<#if changeLogEntryList?has_content>
			<#list changeLogEntryList as clEntry><#if clEntry.Status?has_content> (<@com.picklist clEntry.Status/>)</#if><#if clEntry.Remark?has_content> - <@com.text clEntry.Remark/></#if><#if clEntry?has_next> | </#if></#list>
		</#if>
		</@compress>
	</#local>
	
	<#return changeLogStatusMessage/>
</#function>

<#function getLitIds ref>
	<#local litIds>
		<@compress single_line=true>
			<#list ref.GeneralInfo.StudyIdentifiers as studyId>
				<#if studyId.StudyIDType?has_content><@com.picklist studyId.StudyIDType/>: </#if><@com.text studyId.StudyID/><#if studyId.Remarks?has_content> (<@com.text studyId.Remarks/>)</#if>
				<#if studyId?has_next>|</#if>
			</#list>
		</@compress>
	</#local>
	<#return litIds/>
</#function>


<#macro tableOutput literatureReference sectionName sectionDoc docUrl entityDocument dataPr>
	<#local literatureAuthor = "">
	<#local literatureTitle = "">
	<#local literatureYear = "">
	<#local literatureReportNo = "">
	<#local literatureReportDate = "">
	<#local literatureSource = "">
	<#local literatureSponsor = "">
	<#local literatureType = "">
	<#local literatureLab = "">
	<#local literatureStudyNo = "">
	<#local literatureRemarks = "">
	<#if literatureReference.GeneralInfo.CompanyOwner?has_content>
		<#local literatureSponsor = literatureReference.GeneralInfo.CompanyOwner />
	</#if>
	<#if literatureReference.GeneralInfo.Author?has_content>
		<#local literatureAuthor = literatureReference.GeneralInfo.Author>
	</#if>
	<#if literatureReference.GeneralInfo.Name?has_content>
		<#local literatureTitle = literatureReference.GeneralInfo.Name>
	</#if>
	<#if literatureReference.GeneralInfo.ReferenceYear?has_content>
		<#local literatureYear><@com.number literatureReference.GeneralInfo.ReferenceYear/></#local>
	</#if>
	<#if literatureReference.GeneralInfo.ReportNo?has_content>
		<#local literatureReportNo = literatureReference.GeneralInfo.ReportNo>
	</#if>
	<#if literatureReference.GeneralInfo.ReportDate?has_content>
		<#local literatureReportDate = literatureReference.GeneralInfo.ReportDate>
	</#if>
	<#if literatureReference.GeneralInfo.Source?has_content>
		<#local literatureSource = literatureReference.GeneralInfo.Source>
	</#if>
	<#if literatureReference.GeneralInfo.LiteratureType?has_content>
		<#local literatureType><@com.picklist literatureReference.GeneralInfo.LiteratureType/></#local>
	</#if>
	<#if literatureReference.GeneralInfo.TestLab?has_content>
		<#local literatureLab = literatureReference.GeneralInfo.TestLab>
	</#if>
	<#if literatureReference.GeneralInfo.CompanyOwnerStudyNo?has_content>
		<#local literatureStudyNo = literatureReference.GeneralInfo.CompanyOwnerStudyNo>
	</#if>
	<#if literatureReference.GeneralInfo.Remarks?has_content>
		<#local literatureRemarks = literatureReference.GeneralInfo.Remarks>
	</#if>

	<#local sectionDocTypePath = sectionDoc.documentType + "." + sectionDoc.documentSubType>
	<#local sectionDocType = sectionDoc.documentType>

	<#if sectionDoc.hasElement("AdministrativeData.DataProtection")>
		<#local flag=sectionDoc.AdministrativeData.DataProtection/>
	<#elseif sectionDoc.hasElement("AdministrativeDataSummary.DataProtection")>
		<#local flag=sectionDoc.AdministrativeDataSummary.DataProtection/>
	<#else>
		<#local flag=''>
	<#--missing: in some FLEXIBLE RECORDS: Suppliers, Sites, GhS-->
	<#--  <#local flagPath="DataProtection"/>-->
	</#if>

	<#if sectionDoc.hasElement("MaterialsAndMethods.GLPComplianceStatement") && sectionDoc.MaterialsAndMethods.GLPComplianceStatement?has_content>
		<#local glpData = utils.getPicklistFieldAsText(sectionDoc.MaterialsAndMethods.GLPComplianceStatement)/>
	<#else>
		<#local glpData = 'no GLP information available'/>
	</#if>

	<#if dataPr?has_content && !(dataPr?is_string) >
		<#local dpValue><@com.picklist picklistValue=dataPr printDescription=false printRemarks=false/></#local>
		<#local dpJust><@com.text dataPr.remarks/></#local>
	<#elseif dataProtection?has_content>
		<#local dpValue = dataProtection/>
		<#local dpJust = dataProtection/>
	<#else>
		<#local dpValue	= 'no'/>
		<#local dpJust = ''/>
	</#if>

	<#if pppRelevant??>
		<#local previouslyUsed=getChangeLogStatus(sectionDoc, entityDocument)/>
	</#if>
	<#local litStudyIds=getLitIds(literatureReference)/>

	<@utils.csvValue entityDocument.documentType/>,<@utils.csvValue entityDocument.name/>,<@utils.csvValue sectionName/>,"=HYPERLINK(""${docUrl}"",""${sectionDoc.name}"")",<@utils.csvValue glpData/>,<#if flag?has_content && flag.confidentiality?has_content>yes<#else>no</#if>,<#if flag?has_content && flag.justification?has_content><@utils.csvValue flag.justification/></#if>,<@utils.csvValue dpValue/>,<@utils.csvValue dpJust/>,<#if pppRelevant??><@utils.csvValue previouslyUsed/>,</#if><@utils.csvValue literatureType/>,<@utils.csvValue literatureAuthor/>,<@utils.csvValue literatureTitle/>,<@utils.csvValue literatureYear/>,<@utils.csvValue literatureReportNo/>,<@utils.csvValue literatureReportDate/>,<@utils.csvValue literatureStudyNo/>,<@utils.csvValue literatureSource/>,<@utils.csvValue literatureSponsor/>,<@utils.csvValue literatureLab/>,<@utils.csvValue literatureRemarks/>,<@utils.csvValue litStudyIds/>
</#macro>